# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, StrictBool, StrictInt, StrictStr, conint, constr
from marqeta_client.models.expiration_offset import ExpirationOffset
from marqeta_client.models.fulfillment_response import FulfillmentResponse
from marqeta_client.models.user_association import UserAssociation

class BulkIssuanceResponse(BaseModel):
    """
    BulkIssuanceResponse
    """
    token: constr(strict=True, max_length=36, min_length=1) = ...
    fulfillment: FulfillmentResponse = ...
    expedite: Optional[StrictBool] = False
    card_product_token: constr(strict=True, max_length=36, min_length=1) = ...
    card_allocation: conint(strict=True, le=50000) = ...
    user_association: Optional[UserAssociation] = None
    name_line_1_numeric_postfix: Optional[StrictBool] = False
    name_line_1_random_postfix: Optional[StrictBool] = False
    expiration_offset: Optional[ExpirationOffset] = None
    cards_processed: Optional[StrictInt] = None
    created_time: Optional[datetime] = None
    name_line1_start_index: Optional[StrictInt] = None
    name_line1_end_index: Optional[StrictInt] = None
    card_fulfillment_time: Optional[datetime] = None
    provider_ship_date: Optional[datetime] = None
    provider_shipping_method: Optional[StrictStr] = None
    provider_tracking_number: Optional[StrictStr] = None
    __properties = ["token", "fulfillment", "expedite", "card_product_token", "card_allocation", "user_association", "name_line_1_numeric_postfix", "name_line_1_random_postfix", "expiration_offset", "cards_processed", "created_time", "name_line1_start_index", "name_line1_end_index", "card_fulfillment_time", "provider_ship_date", "provider_shipping_method", "provider_tracking_number"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> BulkIssuanceResponse:
        """Create an instance of BulkIssuanceResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of fulfillment
        if self.fulfillment:
            _dict['fulfillment'] = self.fulfillment.to_dict()
        # override the default output from pydantic by calling `to_dict()` of user_association
        if self.user_association:
            _dict['user_association'] = self.user_association.to_dict()
        # override the default output from pydantic by calling `to_dict()` of expiration_offset
        if self.expiration_offset:
            _dict['expiration_offset'] = self.expiration_offset.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> BulkIssuanceResponse:
        """Create an instance of BulkIssuanceResponse from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return BulkIssuanceResponse.parse_obj(obj)

        _obj = BulkIssuanceResponse.parse_obj({
            "token": obj.get("token"),
            "fulfillment": FulfillmentResponse.from_dict(obj.get("fulfillment")) if obj.get("fulfillment") is not None else None,
            "expedite": obj.get("expedite") if obj.get("expedite") is not None else False,
            "card_product_token": obj.get("card_product_token"),
            "card_allocation": obj.get("card_allocation"),
            "user_association": UserAssociation.from_dict(obj.get("user_association")) if obj.get("user_association") is not None else None,
            "name_line_1_numeric_postfix": obj.get("name_line_1_numeric_postfix") if obj.get("name_line_1_numeric_postfix") is not None else False,
            "name_line_1_random_postfix": obj.get("name_line_1_random_postfix") if obj.get("name_line_1_random_postfix") is not None else False,
            "expiration_offset": ExpirationOffset.from_dict(obj.get("expiration_offset")) if obj.get("expiration_offset") is not None else None,
            "cards_processed": obj.get("cards_processed"),
            "created_time": obj.get("created_time"),
            "name_line1_start_index": obj.get("name_line1_start_index"),
            "name_line1_end_index": obj.get("name_line1_end_index"),
            "card_fulfillment_time": obj.get("card_fulfillment_time"),
            "provider_ship_date": obj.get("provider_ship_date"),
            "provider_shipping_method": obj.get("provider_shipping_method"),
            "provider_tracking_number": obj.get("provider_tracking_number")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, StrictFloat, StrictInt
from marqeta_client.models.cardholder_address_response import CardholderAddressResponse
from marqeta_client.models.funding_source_model import FundingSourceModel
from marqeta_client.models.gateway_log_model import GatewayLogModel

class Funding(BaseModel):
    """
    Funding
    """
    amount: Optional[Union[StrictFloat, StrictInt]] = None
    source: FundingSourceModel = ...
    source_address: Optional[CardholderAddressResponse] = None
    gateway_log: Optional[GatewayLogModel] = None
    __properties = ["amount", "source", "source_address", "gateway_log"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Funding:
        """Create an instance of Funding from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of source
        if self.source:
            _dict['source'] = self.source.to_dict()
        # override the default output from pydantic by calling `to_dict()` of source_address
        if self.source_address:
            _dict['source_address'] = self.source_address.to_dict()
        # override the default output from pydantic by calling `to_dict()` of gateway_log
        if self.gateway_log:
            _dict['gateway_log'] = self.gateway_log.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Funding:
        """Create an instance of Funding from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return Funding.parse_obj(obj)

        _obj = Funding.parse_obj({
            "amount": obj.get("amount"),
            "source": FundingSourceModel.from_dict(obj.get("source")) if obj.get("source") is not None else None,
            "source_address": CardholderAddressResponse.from_dict(obj.get("source_address")) if obj.get("source_address") is not None else None,
            "gateway_log": GatewayLogModel.from_dict(obj.get("gateway_log")) if obj.get("gateway_log") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import re  # noqa: F401

from pydantic import validate_arguments, ValidationError
from typing_extensions import Annotated

from pydantic import Field, StrictInt, StrictStr

from typing import Optional

from marqeta_client.models.digital_wallet_token import DigitalWalletToken
from marqeta_client.models.digital_wallet_token_list_response import DigitalWalletTokenListResponse

from marqeta_client.api_client import ApiClient
from marqeta_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class DigitalWalletTokensApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def get_digitalwallettokens(self, count : Annotated[Optional[StrictInt], Field(description="Number of digital wallet tokens to retrieve")] = None, start_index : Annotated[Optional[StrictInt], Field(description="Start index")] = None, fields : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.")] = None, sort_by : Annotated[Optional[StrictStr], Field(description="Sort order")] = None, start_date : Annotated[Optional[StrictStr], Field(description="Start date (yyyy-MM-dd)")] = None, end_date : Annotated[Optional[StrictStr], Field(description="End date (yyyy-MM-dd)")] = None, pan_reference_id : Annotated[Optional[StrictStr], Field(description="PAN reference ID")] = None, token_reference_id : Annotated[Optional[StrictStr], Field(description="Token reference ID")] = None, correlation_id : Annotated[Optional[StrictStr], Field(description="Correlation ID")] = None, token_type : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of digital wallet token types to display e.g. DEVICE_SECURE_ELEMENT | MERCHANT_CARD_ON_FILE | DEVICE_CLOUD_BASED | ECOMMERCE_DIGITAL_WALLET | PSEUDO_ACCOUNT")] = None, token_requestor_name : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of digital wallet token wallet providers to display e.g. APPLE_PAY | ANDROID_PAY| SAMSUNG_PAY | MICROSOFT_PAY | VISA_CHECKOUT | FACEBOOK | NETFLIX | UNKNOWN")] = None, state : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of digital wallet token states to display e.g. REQUESTED | REQUEST_DECLINED | TERMINATED | SUSPENDED | ACTIVE")] = None, embed : Annotated[Optional[StrictStr], Field(description="Embed")] = None, **kwargs) -> DigitalWalletTokenListResponse:  # noqa: E501
        """Returns digital wallet tokens  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_digitalwallettokens(count, start_index, fields, sort_by, start_date, end_date, pan_reference_id, token_reference_id, correlation_id, token_type, token_requestor_name, state, embed, async_req=True)
        >>> result = thread.get()

        :param count: Number of digital wallet tokens to retrieve
        :type count: int
        :param start_index: Start index
        :type start_index: int
        :param fields: Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.
        :type fields: str
        :param sort_by: Sort order
        :type sort_by: str
        :param start_date: Start date (yyyy-MM-dd)
        :type start_date: str
        :param end_date: End date (yyyy-MM-dd)
        :type end_date: str
        :param pan_reference_id: PAN reference ID
        :type pan_reference_id: str
        :param token_reference_id: Token reference ID
        :type token_reference_id: str
        :param correlation_id: Correlation ID
        :type correlation_id: str
        :param token_type: Comma-delimited list of digital wallet token types to display e.g. DEVICE_SECURE_ELEMENT | MERCHANT_CARD_ON_FILE | DEVICE_CLOUD_BASED | ECOMMERCE_DIGITAL_WALLET | PSEUDO_ACCOUNT
        :type token_type: str
        :param token_requestor_name: Comma-delimited list of digital wallet token wallet providers to display e.g. APPLE_PAY | ANDROID_PAY| SAMSUNG_PAY | MICROSOFT_PAY | VISA_CHECKOUT | FACEBOOK | NETFLIX | UNKNOWN
        :type token_requestor_name: str
        :param state: Comma-delimited list of digital wallet token states to display e.g. REQUESTED | REQUEST_DECLINED | TERMINATED | SUSPENDED | ACTIVE
        :type state: str
        :param embed: Embed
        :type embed: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DigitalWalletTokenListResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.get_digitalwallettokens_with_http_info(count, start_index, fields, sort_by, start_date, end_date, pan_reference_id, token_reference_id, correlation_id, token_type, token_requestor_name, state, embed, **kwargs)  # noqa: E501

    @validate_arguments
    def get_digitalwallettokens_with_http_info(self, count : Annotated[Optional[StrictInt], Field(description="Number of digital wallet tokens to retrieve")] = None, start_index : Annotated[Optional[StrictInt], Field(description="Start index")] = None, fields : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.")] = None, sort_by : Annotated[Optional[StrictStr], Field(description="Sort order")] = None, start_date : Annotated[Optional[StrictStr], Field(description="Start date (yyyy-MM-dd)")] = None, end_date : Annotated[Optional[StrictStr], Field(description="End date (yyyy-MM-dd)")] = None, pan_reference_id : Annotated[Optional[StrictStr], Field(description="PAN reference ID")] = None, token_reference_id : Annotated[Optional[StrictStr], Field(description="Token reference ID")] = None, correlation_id : Annotated[Optional[StrictStr], Field(description="Correlation ID")] = None, token_type : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of digital wallet token types to display e.g. DEVICE_SECURE_ELEMENT | MERCHANT_CARD_ON_FILE | DEVICE_CLOUD_BASED | ECOMMERCE_DIGITAL_WALLET | PSEUDO_ACCOUNT")] = None, token_requestor_name : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of digital wallet token wallet providers to display e.g. APPLE_PAY | ANDROID_PAY| SAMSUNG_PAY | MICROSOFT_PAY | VISA_CHECKOUT | FACEBOOK | NETFLIX | UNKNOWN")] = None, state : Annotated[Optional[StrictStr], Field(description="Comma-delimited list of digital wallet token states to display e.g. REQUESTED | REQUEST_DECLINED | TERMINATED | SUSPENDED | ACTIVE")] = None, embed : Annotated[Optional[StrictStr], Field(description="Embed")] = None, **kwargs):  # noqa: E501
        """Returns digital wallet tokens  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_digitalwallettokens_with_http_info(count, start_index, fields, sort_by, start_date, end_date, pan_reference_id, token_reference_id, correlation_id, token_type, token_requestor_name, state, embed, async_req=True)
        >>> result = thread.get()

        :param count: Number of digital wallet tokens to retrieve
        :type count: int
        :param start_index: Start index
        :type start_index: int
        :param fields: Comma-delimited list of fields to return (e.g. field_1,field_2,..). Leave blank to return all fields.
        :type fields: str
        :param sort_by: Sort order
        :type sort_by: str
        :param start_date: Start date (yyyy-MM-dd)
        :type start_date: str
        :param end_date: End date (yyyy-MM-dd)
        :type end_date: str
        :param pan_reference_id: PAN reference ID
        :type pan_reference_id: str
        :param token_reference_id: Token reference ID
        :type token_reference_id: str
        :param correlation_id: Correlation ID
        :type correlation_id: str
        :param token_type: Comma-delimited list of digital wallet token types to display e.g. DEVICE_SECURE_ELEMENT | MERCHANT_CARD_ON_FILE | DEVICE_CLOUD_BASED | ECOMMERCE_DIGITAL_WALLET | PSEUDO_ACCOUNT
        :type token_type: str
        :param token_requestor_name: Comma-delimited list of digital wallet token wallet providers to display e.g. APPLE_PAY | ANDROID_PAY| SAMSUNG_PAY | MICROSOFT_PAY | VISA_CHECKOUT | FACEBOOK | NETFLIX | UNKNOWN
        :type token_requestor_name: str
        :param state: Comma-delimited list of digital wallet token states to display e.g. REQUESTED | REQUEST_DECLINED | TERMINATED | SUSPENDED | ACTIVE
        :type state: str
        :param embed: Embed
        :type embed: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(DigitalWalletTokenListResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'count',
            'start_index',
            'fields',
            'sort_by',
            'start_date',
            'end_date',
            'pan_reference_id',
            'token_reference_id',
            'correlation_id',
            'token_type',
            'token_requestor_name',
            'state',
            'embed'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_digitalwallettokens" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('count') is not None:  # noqa: E501
            _query_params.append(('count', _params['count']))

        if _params.get('start_index') is not None:  # noqa: E501
            _query_params.append(('start_index', _params['start_index']))

        if _params.get('fields') is not None:  # noqa: E501
            _query_params.append(('fields', _params['fields']))

        if _params.get('sort_by') is not None:  # noqa: E501
            _query_params.append(('sort_by', _params['sort_by']))

        if _params.get('start_date') is not None:  # noqa: E501
            _query_params.append(('start_date', _params['start_date']))

        if _params.get('end_date') is not None:  # noqa: E501
            _query_params.append(('end_date', _params['end_date']))

        if _params.get('pan_reference_id') is not None:  # noqa: E501
            _query_params.append(('pan_reference_id', _params['pan_reference_id']))

        if _params.get('token_reference_id') is not None:  # noqa: E501
            _query_params.append(('token_reference_id', _params['token_reference_id']))

        if _params.get('correlation_id') is not None:  # noqa: E501
            _query_params.append(('correlation_id', _params['correlation_id']))

        if _params.get('token_type') is not None:  # noqa: E501
            _query_params.append(('token_type', _params['token_type']))

        if _params.get('token_requestor_name') is not None:  # noqa: E501
            _query_params.append(('token_requestor_name', _params['token_requestor_name']))

        if _params.get('state') is not None:  # noqa: E501
            _query_params.append(('state', _params['state']))

        if _params.get('embed') is not None:  # noqa: E501
            _query_params.append(('embed', _params['embed'].value))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "DigitalWalletTokenListResponse",
            '400': None,
            '500': None,
        }

        return self.api_client.call_api(
            '/digitalwallettokens', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_digitalwallettokens_card_cardtoken(self, card_token : Annotated[StrictStr, Field(..., description="Card token")], count : Annotated[Optional[StrictInt], Field(description="Number of items to retrieve")] = None, start_index : Annotated[Optional[StrictInt], Field(description="Start index")] = None, sort_by : Annotated[Optional[StrictStr], Field(description="Sort order")] = None, **kwargs) -> DigitalWalletTokenListResponse:  # noqa: E501
        """Returns a list of digital wallet tokens for the specified card  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_digitalwallettokens_card_cardtoken(card_token, count, start_index, sort_by, async_req=True)
        >>> result = thread.get()

        :param card_token: Card token (required)
        :type card_token: str
        :param count: Number of items to retrieve
        :type count: int
        :param start_index: Start index
        :type start_index: int
        :param sort_by: Sort order
        :type sort_by: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DigitalWalletTokenListResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.get_digitalwallettokens_card_cardtoken_with_http_info(card_token, count, start_index, sort_by, **kwargs)  # noqa: E501

    @validate_arguments
    def get_digitalwallettokens_card_cardtoken_with_http_info(self, card_token : Annotated[StrictStr, Field(..., description="Card token")], count : Annotated[Optional[StrictInt], Field(description="Number of items to retrieve")] = None, start_index : Annotated[Optional[StrictInt], Field(description="Start index")] = None, sort_by : Annotated[Optional[StrictStr], Field(description="Sort order")] = None, **kwargs):  # noqa: E501
        """Returns a list of digital wallet tokens for the specified card  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_digitalwallettokens_card_cardtoken_with_http_info(card_token, count, start_index, sort_by, async_req=True)
        >>> result = thread.get()

        :param card_token: Card token (required)
        :type card_token: str
        :param count: Number of items to retrieve
        :type count: int
        :param start_index: Start index
        :type start_index: int
        :param sort_by: Sort order
        :type sort_by: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(DigitalWalletTokenListResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'card_token',
            'count',
            'start_index',
            'sort_by'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_digitalwallettokens_card_cardtoken" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['card_token']:
            _path_params['card_token'] = _params['card_token']


        # process the query parameters
        _query_params = []
        if _params.get('count') is not None:  # noqa: E501
            _query_params.append(('count', _params['count']))

        if _params.get('start_index') is not None:  # noqa: E501
            _query_params.append(('start_index', _params['start_index']))

        if _params.get('sort_by') is not None:  # noqa: E501
            _query_params.append(('sort_by', _params['sort_by']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "DigitalWalletTokenListResponse",
            '400': None,
            '404': None,
            '500': None,
        }

        return self.api_client.call_api(
            '/digitalwallettokens/card/{card_token}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_digitalwallettokens_token(self, token : Annotated[StrictStr, Field(..., description="Digital wallet token")], **kwargs) -> DigitalWalletToken:  # noqa: E501
        """Returns a specific digital wallet token  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_digitalwallettokens_token(token, async_req=True)
        >>> result = thread.get()

        :param token: Digital wallet token (required)
        :type token: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DigitalWalletToken
        """
        kwargs['_return_http_data_only'] = True
        return self.get_digitalwallettokens_token_with_http_info(token, **kwargs)  # noqa: E501

    @validate_arguments
    def get_digitalwallettokens_token_with_http_info(self, token : Annotated[StrictStr, Field(..., description="Digital wallet token")], **kwargs):  # noqa: E501
        """Returns a specific digital wallet token  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_digitalwallettokens_token_with_http_info(token, async_req=True)
        >>> result = thread.get()

        :param token: Digital wallet token (required)
        :type token: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(DigitalWalletToken, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'token'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_digitalwallettokens_token" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['token']:
            _path_params['token'] = _params['token']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "DigitalWalletToken",
            '400': None,
            '404': None,
            '500': None,
        }

        return self.api_client.call_api(
            '/digitalwallettokens/{token}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_digitalwallettokens_token_showtokenpan(self, token : Annotated[StrictStr, Field(..., description="Digital wallet token")], **kwargs) -> DigitalWalletToken:  # noqa: E501
        """Returns a specific digital wallet token PAN visible  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_digitalwallettokens_token_showtokenpan(token, async_req=True)
        >>> result = thread.get()

        :param token: Digital wallet token (required)
        :type token: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DigitalWalletToken
        """
        kwargs['_return_http_data_only'] = True
        return self.get_digitalwallettokens_token_showtokenpan_with_http_info(token, **kwargs)  # noqa: E501

    @validate_arguments
    def get_digitalwallettokens_token_showtokenpan_with_http_info(self, token : Annotated[StrictStr, Field(..., description="Digital wallet token")], **kwargs):  # noqa: E501
        """Returns a specific digital wallet token PAN visible  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_digitalwallettokens_token_showtokenpan_with_http_info(token, async_req=True)
        >>> result = thread.get()

        :param token: Digital wallet token (required)
        :type token: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(DigitalWalletToken, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'token'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_digitalwallettokens_token_showtokenpan" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['token']:
            _path_params['token'] = _params['token']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "DigitalWalletToken",
            '400': None,
            '404': None,
            '500': None,
        }

        return self.api_client.call_api(
            '/digitalwallettokens/{token}/showtokenpan', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))



# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictBool, StrictStr, constr
from marqeta_client.models.auto_reload_association import AutoReloadAssociation
from marqeta_client.models.order_scope import OrderScope

class AutoReloadUpdateModel(BaseModel):
    """
    AutoReloadUpdateModel
    """
    token: Optional[constr(strict=True, max_length=36, min_length=1)] = None
    active: Optional[StrictBool] = True
    funding_source_token: Optional[constr(strict=True, max_length=36, min_length=1)] = None
    funding_source_address_token: Optional[constr(strict=True, max_length=36, min_length=1)] = None
    association: Optional[AutoReloadAssociation] = None
    order_scope: Optional[OrderScope] = None
    currency_code: Optional[StrictStr] = None
    __properties = ["token", "active", "funding_source_token", "funding_source_address_token", "association", "order_scope", "currency_code"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AutoReloadUpdateModel:
        """Create an instance of AutoReloadUpdateModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of association
        if self.association:
            _dict['association'] = self.association.to_dict()
        # override the default output from pydantic by calling `to_dict()` of order_scope
        if self.order_scope:
            _dict['order_scope'] = self.order_scope.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AutoReloadUpdateModel:
        """Create an instance of AutoReloadUpdateModel from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return AutoReloadUpdateModel.parse_obj(obj)

        _obj = AutoReloadUpdateModel.parse_obj({
            "token": obj.get("token"),
            "active": obj.get("active") if obj.get("active") is not None else True,
            "funding_source_token": obj.get("funding_source_token"),
            "funding_source_address_token": obj.get("funding_source_address_token"),
            "association": AutoReloadAssociation.from_dict(obj.get("association")) if obj.get("association") is not None else None,
            "order_scope": OrderScope.from_dict(obj.get("order_scope")) if obj.get("order_scope") is not None else None,
            "currency_code": obj.get("currency_code")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, StrictStr, validator

class DirectDepositTransitionResponse(BaseModel):
    """
    DirectDepositTransitionResponse
    """
    channel: Optional[StrictStr] = None
    token: Optional[StrictStr] = None
    reason: Optional[StrictStr] = None
    type: Optional[StrictStr] = None
    direct_deposit_token: Optional[StrictStr] = None
    transaction_token: Optional[StrictStr] = None
    state: Optional[StrictStr] = None
    reason_code: Optional[StrictStr] = None
    created_time: Optional[datetime] = None
    direct_deposit_account_token: Optional[StrictStr] = None
    __properties = ["channel", "token", "reason", "type", "direct_deposit_token", "transaction_token", "state", "reason_code", "created_time", "direct_deposit_account_token"]

    @validator('channel')
    def channel_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('API', 'IVR', 'FRAUD', 'ADMIN', 'SYSTEM', 'NETWORK', 'PROD_SUPPORT', 'UNSUPPORTED'):
            raise ValueError("must be one of enum values ('API', 'IVR', 'FRAUD', 'ADMIN', 'SYSTEM', 'NETWORK', 'PROD_SUPPORT', 'UNSUPPORTED')")
        return v

    @validator('state')
    def state_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('PENDING', 'APPLIED', 'REVERSED', 'REJECTED'):
            raise ValueError("must be one of enum values ('PENDING', 'APPLIED', 'REVERSED', 'REJECTED')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> DirectDepositTransitionResponse:
        """Create an instance of DirectDepositTransitionResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> DirectDepositTransitionResponse:
        """Create an instance of DirectDepositTransitionResponse from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return DirectDepositTransitionResponse.parse_obj(obj)

        _obj = DirectDepositTransitionResponse.parse_obj({
            "channel": obj.get("channel"),
            "token": obj.get("token"),
            "reason": obj.get("reason"),
            "type": obj.get("type"),
            "direct_deposit_token": obj.get("direct_deposit_token"),
            "transaction_token": obj.get("transaction_token"),
            "state": obj.get("state"),
            "reason_code": obj.get("reason_code"),
            "created_time": obj.get("created_time"),
            "direct_deposit_account_token": obj.get("direct_deposit_account_token")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr, conlist, constr
from marqeta_client.models.fee_model import FeeModel

class ProgramTransfer(BaseModel):
    """
    ProgramTransfer
    """
    token: Optional[constr(strict=True, max_length=36, min_length=1)] = None
    user_token: Optional[constr(strict=True, max_length=36, min_length=1)] = Field(None, description="Required if 'business_token' is null")
    business_token: Optional[constr(strict=True, max_length=36, min_length=1)] = Field(None, description="Required if 'user_token' is null")
    amount: Union[StrictFloat, StrictInt] = ...
    type_token: constr(strict=True, max_length=36, min_length=1) = ...
    tags: Optional[constr(strict=True, max_length=255, min_length=1)] = None
    memo: Optional[constr(strict=True, max_length=99, min_length=1)] = None
    currency_code: StrictStr = ...
    fees: Optional[conlist(FeeModel)] = None
    __properties = ["token", "user_token", "business_token", "amount", "type_token", "tags", "memo", "currency_code", "fees"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ProgramTransfer:
        """Create an instance of ProgramTransfer from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in fees (list)
        _items = []
        if self.fees:
            for _item in self.fees:
                if _item:
                    _items.append(_item.to_dict())
            _dict['fees'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ProgramTransfer:
        """Create an instance of ProgramTransfer from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return ProgramTransfer.parse_obj(obj)

        _obj = ProgramTransfer.parse_obj({
            "token": obj.get("token"),
            "user_token": obj.get("user_token"),
            "business_token": obj.get("business_token"),
            "amount": obj.get("amount"),
            "type_token": obj.get("type_token"),
            "tags": obj.get("tags"),
            "memo": obj.get("memo"),
            "currency_code": obj.get("currency_code"),
            "fees": [FeeModel.from_dict(_item) for _item in obj.get("fees")] if obj.get("fees") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictBool, StrictInt, StrictStr

class InternalAccount(BaseModel):
    """
    InternalAccount
    """
    id: StrictInt = ...
    code: StrictStr = ...
    subclass: StrictStr = ...
    final_account: Optional[StrictBool] = None
    cardholder_account: Optional[StrictBool] = None
    __properties = ["id", "code", "subclass", "final_account", "cardholder_account"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> InternalAccount:
        """Create an instance of InternalAccount from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> InternalAccount:
        """Create an instance of InternalAccount from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return InternalAccount.parse_obj(obj)

        _obj = InternalAccount.parse_obj({
            "id": obj.get("id"),
            "code": obj.get("code"),
            "subclass": obj.get("subclass"),
            "final_account": obj.get("final_account"),
            "cardholder_account": obj.get("cardholder_account")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional, Union
from pydantic import BaseModel, StrictFloat, StrictInt, StrictStr, validator
from marqeta_client.models.address_verification_model import AddressVerificationModel
from marqeta_client.models.transaction_card_acceptor_view_model_v1 import TransactionCardAcceptorViewModelV1

class FraudStreamRequest(BaseModel):
    """
    FraudStreamRequest
    """
    program: Optional[StrictStr] = None
    type: Optional[StrictStr] = None
    state: Optional[StrictStr] = None
    itc: Optional[StrictStr] = None
    token: Optional[StrictStr] = None
    user_token: Optional[StrictStr] = None
    acting_user_token: Optional[StrictStr] = None
    card_token: Optional[StrictStr] = None
    user_transaction_time: Optional[datetime] = None
    request_amount: Optional[Union[StrictFloat, StrictInt]] = None
    amount: Optional[Union[StrictFloat, StrictInt]] = None
    currency_code: Optional[StrictStr] = None
    network: Optional[StrictStr] = None
    account_risk_score: Optional[StrictStr] = None
    account_risk_score_reason_code: Optional[StrictStr] = None
    transaction_risk_score: Optional[StrictInt] = None
    transaction_risk_score_reason_code: Optional[StrictStr] = None
    card_acceptor: Optional[TransactionCardAcceptorViewModelV1] = None
    address_verification: Optional[AddressVerificationModel] = None
    __properties = ["program", "type", "state", "itc", "token", "user_token", "acting_user_token", "card_token", "user_transaction_time", "request_amount", "amount", "currency_code", "network", "account_risk_score", "account_risk_score_reason_code", "transaction_risk_score", "transaction_risk_score_reason_code", "card_acceptor", "address_verification"]

    @validator('type')
    def type_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('gpa.credit.pending', 'gpa.credit.pending.reversal', 'gpa.credit.reversal', 'gpa.credit', 'gpa.debit', 'gpa.debit.pending', 'gpa.debit.pending.reversal', 'gpa.debit.reversal', 'gpa.grant', 'gpa.credit.networkload', 'gpa.credit.networkload.clearing', 'gpa.credit.networkload.reversal', 'gpa.debit.networkload', 'gpa.debit.networkload.clearing', 'gpa.debit.networkload.reversal', 'original.credit.authorization', 'original.credit.authorization.clearing', 'original.credit.authorization.reversal', 'original.credit.auth_plus_capture', 'original.credit.auth_plus_capture.reversal', 'gpa.credit.issueroperator', 'gpa.debit.issueroperator', 'gpa.debit.authorization', 'gpa.credit.authorization', 'gpa.credit.authorization.reversal', 'gpa.credit.chargeback', 'gpa.credit.chargeback.reversal', 'gpa.credit.billpayment', 'gpa.credit.authorization.billpayment', 'gpa.credit.authorization.billpayment.reversal', 'msa.credit.pending', 'msa.credit.pending.reversal', 'msa.credit.reversal', 'msa.credit', 'msa.debit.reversal', 'msa.debit.pending.reversal', 'msa.debit', 'msa.credit.authorization', 'msa.credit.authorization.reversal', 'msa.credit.chargeback', 'msa.credit.chargeback.reversal', 'authorization', 'authorization.incremental', 'authorization.advice', 'authorization.reversal', 'authorization.cashback', 'authorization.quasi.cash', 'authorization.atm.withdrawal', 'authorization.clearing', 'authorization.clearing.network.fee', 'authorization.clearing.representment', 'authorization.reversal.issuerexpiration', 'dispute.credit', 'dispute.debit', 'chargeback.pfs.debit', 'chargeback.pfs.pending.debit', 'chargeback.pfs.credit', 'authorization.clearing.chargeback', 'authorization.clearing.chargeback.reversal', 'authorization.clearing.chargeback.completed', 'authorization.clearing.chargeback.provisional.credit', 'authorization.clearing.chargeback.provisional.debit', 'authorization.clearing.chargeback.writeoff', 'authorization.clearing.cashback', 'authorization.clearing.quasi.cash', 'authorization.clearing.atm.withdrawal', 'account.funding.authorization', 'account.funding.authorization.clearing', 'account.funding.auth_plus_capture', 'account.funding.authorization.reversal', 'account.funding.auth_plus_capture.reversal', 'address.verification', 'balanceinquiry', 'refund', 'pindebit.credit.adjustment', 'pindebit.debit.adjustment', 'pindebit.atm.withdrawal', 'pindebit.quasi.cash', 'pindebit.balanceinquiry', 'pindebit.cashback', 'pindebit.checkavs', 'pindebit.financial.deposit', 'pindebit.refund', 'pindebit.reversal', 'pindebit.refund.reversal', 'pindebit.transfer', 'pindebit', 'pindebit.representment', 'pindebit.authorization', 'pindebit.authorization.clearing', 'pindebit.authorization.reversal', 'pindebit.authorization.reversal.issuerexpiration', 'pindebit.chargeback', 'pindebit.chargeback.reversal', 'pindebit.chargeback.completed', 'pindebit.chargeback.provisional.credit', 'pindebit.chargeback.provisional.debit', 'pindebit.chargeback.writeoff', 'directdeposit.credit', 'directdeposit.debit', 'directdeposit.credit.pending', 'directdeposit.debit.pending', 'directdeposit.credit.reject', 'directdeposit.debit.reject', 'directdeposit.credit.pending.reversal', 'directdeposit.debit.pending.reversal', 'directdeposit.credit.reversal', 'directdeposit.debit.reversal', 'fee.charge.pending', 'fee.charge', 'fee.charge.pending.refund', 'funds.expire', 'programreserve.credit', 'programreserve.debit', 'reward.earn', 'transfer.peer', 'transfer.fee', 'account.credit', 'account.debit', 'transfer.program', 'token.activation-request', 'token.advice', 'pushtocard.debit', 'pushtocard.pending', 'pushtocard.reversal', 'billpayment', 'billpayment.clearing', 'billpayment.reversal', 'refund.authorization', 'refund.authorization.clearing', 'refund.authorization.reversal', 'ach.early.funds', 'ach.early.funds.reversed', 'ach.push.pending', 'ach.pull.pending', 'ach.push', 'ach.pull', 'ach.cancel', 'ach.returned', 'ach.pull.returned', 'ach.push.returned', 'ach.provisional.credit', 'ach.provisional.credit.reversed', 'ach.push.reversal.completed', 'ach.push.reversal.declined', 'ach.jit.push.pending', 'ach.jit.pull.pending', 'ach.jit.push', 'ach.jit.pull', 'ach.jit.cancel', 'ach.jit.pull.returned', 'ach.jit.push.returned', 'check.return.debit', 'check.return.debit.reversal', 'check.clearing.debit', 'accountfunding.pull', 'accountfunding.pull.chargeback', 'escheatment.debit', 'escheatment.debit.reversal', 'escheatment.debit.clearing', 'zero.clearing', 'credit.adjustment', 'debit.adjustment', 'account.transfer', 'account.transfer.reversal', 'unknown'):
            raise ValueError("must be one of enum values ('gpa.credit.pending', 'gpa.credit.pending.reversal', 'gpa.credit.reversal', 'gpa.credit', 'gpa.debit', 'gpa.debit.pending', 'gpa.debit.pending.reversal', 'gpa.debit.reversal', 'gpa.grant', 'gpa.credit.networkload', 'gpa.credit.networkload.clearing', 'gpa.credit.networkload.reversal', 'gpa.debit.networkload', 'gpa.debit.networkload.clearing', 'gpa.debit.networkload.reversal', 'original.credit.authorization', 'original.credit.authorization.clearing', 'original.credit.authorization.reversal', 'original.credit.auth_plus_capture', 'original.credit.auth_plus_capture.reversal', 'gpa.credit.issueroperator', 'gpa.debit.issueroperator', 'gpa.debit.authorization', 'gpa.credit.authorization', 'gpa.credit.authorization.reversal', 'gpa.credit.chargeback', 'gpa.credit.chargeback.reversal', 'gpa.credit.billpayment', 'gpa.credit.authorization.billpayment', 'gpa.credit.authorization.billpayment.reversal', 'msa.credit.pending', 'msa.credit.pending.reversal', 'msa.credit.reversal', 'msa.credit', 'msa.debit.reversal', 'msa.debit.pending.reversal', 'msa.debit', 'msa.credit.authorization', 'msa.credit.authorization.reversal', 'msa.credit.chargeback', 'msa.credit.chargeback.reversal', 'authorization', 'authorization.incremental', 'authorization.advice', 'authorization.reversal', 'authorization.cashback', 'authorization.quasi.cash', 'authorization.atm.withdrawal', 'authorization.clearing', 'authorization.clearing.network.fee', 'authorization.clearing.representment', 'authorization.reversal.issuerexpiration', 'dispute.credit', 'dispute.debit', 'chargeback.pfs.debit', 'chargeback.pfs.pending.debit', 'chargeback.pfs.credit', 'authorization.clearing.chargeback', 'authorization.clearing.chargeback.reversal', 'authorization.clearing.chargeback.completed', 'authorization.clearing.chargeback.provisional.credit', 'authorization.clearing.chargeback.provisional.debit', 'authorization.clearing.chargeback.writeoff', 'authorization.clearing.cashback', 'authorization.clearing.quasi.cash', 'authorization.clearing.atm.withdrawal', 'account.funding.authorization', 'account.funding.authorization.clearing', 'account.funding.auth_plus_capture', 'account.funding.authorization.reversal', 'account.funding.auth_plus_capture.reversal', 'address.verification', 'balanceinquiry', 'refund', 'pindebit.credit.adjustment', 'pindebit.debit.adjustment', 'pindebit.atm.withdrawal', 'pindebit.quasi.cash', 'pindebit.balanceinquiry', 'pindebit.cashback', 'pindebit.checkavs', 'pindebit.financial.deposit', 'pindebit.refund', 'pindebit.reversal', 'pindebit.refund.reversal', 'pindebit.transfer', 'pindebit', 'pindebit.representment', 'pindebit.authorization', 'pindebit.authorization.clearing', 'pindebit.authorization.reversal', 'pindebit.authorization.reversal.issuerexpiration', 'pindebit.chargeback', 'pindebit.chargeback.reversal', 'pindebit.chargeback.completed', 'pindebit.chargeback.provisional.credit', 'pindebit.chargeback.provisional.debit', 'pindebit.chargeback.writeoff', 'directdeposit.credit', 'directdeposit.debit', 'directdeposit.credit.pending', 'directdeposit.debit.pending', 'directdeposit.credit.reject', 'directdeposit.debit.reject', 'directdeposit.credit.pending.reversal', 'directdeposit.debit.pending.reversal', 'directdeposit.credit.reversal', 'directdeposit.debit.reversal', 'fee.charge.pending', 'fee.charge', 'fee.charge.pending.refund', 'funds.expire', 'programreserve.credit', 'programreserve.debit', 'reward.earn', 'transfer.peer', 'transfer.fee', 'account.credit', 'account.debit', 'transfer.program', 'token.activation-request', 'token.advice', 'pushtocard.debit', 'pushtocard.pending', 'pushtocard.reversal', 'billpayment', 'billpayment.clearing', 'billpayment.reversal', 'refund.authorization', 'refund.authorization.clearing', 'refund.authorization.reversal', 'ach.early.funds', 'ach.early.funds.reversed', 'ach.push.pending', 'ach.pull.pending', 'ach.push', 'ach.pull', 'ach.cancel', 'ach.returned', 'ach.pull.returned', 'ach.push.returned', 'ach.provisional.credit', 'ach.provisional.credit.reversed', 'ach.push.reversal.completed', 'ach.push.reversal.declined', 'ach.jit.push.pending', 'ach.jit.pull.pending', 'ach.jit.push', 'ach.jit.pull', 'ach.jit.cancel', 'ach.jit.pull.returned', 'ach.jit.push.returned', 'check.return.debit', 'check.return.debit.reversal', 'check.clearing.debit', 'accountfunding.pull', 'accountfunding.pull.chargeback', 'escheatment.debit', 'escheatment.debit.reversal', 'escheatment.debit.clearing', 'zero.clearing', 'credit.adjustment', 'debit.adjustment', 'account.transfer', 'account.transfer.reversal', 'unknown')")
        return v

    @validator('state')
    def state_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('PENDING', 'CLEARED', 'COMPLETION', 'DECLINED', 'ERROR', 'ALL'):
            raise ValueError("must be one of enum values ('PENDING', 'CLEARED', 'COMPLETION', 'DECLINED', 'ERROR', 'ALL')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> FraudStreamRequest:
        """Create an instance of FraudStreamRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of card_acceptor
        if self.card_acceptor:
            _dict['card_acceptor'] = self.card_acceptor.to_dict()
        # override the default output from pydantic by calling `to_dict()` of address_verification
        if self.address_verification:
            _dict['address_verification'] = self.address_verification.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> FraudStreamRequest:
        """Create an instance of FraudStreamRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return FraudStreamRequest.parse_obj(obj)

        _obj = FraudStreamRequest.parse_obj({
            "program": obj.get("program"),
            "type": obj.get("type"),
            "state": obj.get("state"),
            "itc": obj.get("itc"),
            "token": obj.get("token"),
            "user_token": obj.get("user_token"),
            "acting_user_token": obj.get("acting_user_token"),
            "card_token": obj.get("card_token"),
            "user_transaction_time": obj.get("user_transaction_time"),
            "request_amount": obj.get("request_amount"),
            "amount": obj.get("amount"),
            "currency_code": obj.get("currency_code"),
            "network": obj.get("network"),
            "account_risk_score": obj.get("account_risk_score"),
            "account_risk_score_reason_code": obj.get("account_risk_score_reason_code"),
            "transaction_risk_score": obj.get("transaction_risk_score"),
            "transaction_risk_score_reason_code": obj.get("transaction_risk_score_reason_code"),
            "card_acceptor": TransactionCardAcceptorViewModelV1.from_dict(obj.get("card_acceptor")) if obj.get("card_acceptor") is not None else None,
            "address_verification": AddressVerificationModel.from_dict(obj.get("address_verification")) if obj.get("address_verification") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, StrictBool, StrictInt, StrictStr, conlist
from marqeta_client.models.riskcontrol_tags import RiskcontrolTags
from marqeta_client.models.triggered_rule import TriggeredRule

class Issuer(BaseModel):
    """
    Issuer
    """
    success: Optional[StrictBool] = False
    fraud_score: Optional[StrictInt] = None
    fraud_rating: Optional[StrictStr] = None
    rule_violations: Optional[conlist(StrictStr)] = None
    fraud_score_reasons: Optional[conlist(StrictStr)] = None
    recommended_action: Optional[StrictStr] = None
    model: Optional[StrictStr] = None
    message: Optional[StrictStr] = None
    riskcontrol_tags: Optional[conlist(RiskcontrolTags)] = None
    triggered_rules: Optional[conlist(TriggeredRule)] = None
    __properties = ["success", "fraud_score", "fraud_rating", "rule_violations", "fraud_score_reasons", "recommended_action", "model", "message", "riskcontrol_tags", "triggered_rules"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Issuer:
        """Create an instance of Issuer from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in riskcontrol_tags (list)
        _items = []
        if self.riskcontrol_tags:
            for _item in self.riskcontrol_tags:
                if _item:
                    _items.append(_item.to_dict())
            _dict['riskcontrol_tags'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in triggered_rules (list)
        _items = []
        if self.triggered_rules:
            for _item in self.triggered_rules:
                if _item:
                    _items.append(_item.to_dict())
            _dict['triggered_rules'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Issuer:
        """Create an instance of Issuer from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return Issuer.parse_obj(obj)

        _obj = Issuer.parse_obj({
            "success": obj.get("success") if obj.get("success") is not None else False,
            "fraud_score": obj.get("fraud_score"),
            "fraud_rating": obj.get("fraud_rating"),
            "rule_violations": obj.get("rule_violations"),
            "fraud_score_reasons": obj.get("fraud_score_reasons"),
            "recommended_action": obj.get("recommended_action"),
            "model": obj.get("model"),
            "message": obj.get("message"),
            "riskcontrol_tags": [RiskcontrolTags.from_dict(_item) for _item in obj.get("riskcontrol_tags")] if obj.get("riskcontrol_tags") is not None else None,
            "triggered_rules": [TriggeredRule.from_dict(_item) for _item in obj.get("triggered_rules")] if obj.get("triggered_rules") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, StrictBool, StrictStr, conlist

class CommandoModeEnables(BaseModel):
    """
    CommandoModeEnables
    """
    program_funding_source: StrictStr = ...
    velocity_controls: Optional[conlist(StrictStr, max_items=2147483647, min_items=1)] = None
    auth_controls: Optional[conlist(StrictStr)] = None
    ignore_card_suspended_state: Optional[StrictBool] = False
    use_cache_balance: Optional[StrictBool] = False
    __properties = ["program_funding_source", "velocity_controls", "auth_controls", "ignore_card_suspended_state", "use_cache_balance"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CommandoModeEnables:
        """Create an instance of CommandoModeEnables from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CommandoModeEnables:
        """Create an instance of CommandoModeEnables from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return CommandoModeEnables.parse_obj(obj)

        _obj = CommandoModeEnables.parse_obj({
            "program_funding_source": obj.get("program_funding_source"),
            "velocity_controls": obj.get("velocity_controls"),
            "auth_controls": obj.get("auth_controls"),
            "ignore_card_suspended_state": obj.get("ignore_card_suspended_state") if obj.get("ignore_card_suspended_state") is not None else False,
            "use_cache_balance": obj.get("use_cache_balance") if obj.get("use_cache_balance") is not None else False
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictStr, validator
from marqeta_client.models.card_personalization import CardPersonalization
from marqeta_client.models.shipping_information_response import ShippingInformationResponse

class CardFulfillmentResponse(BaseModel):
    """
    CardFulfillmentResponse
    """
    shipping: Optional[ShippingInformationResponse] = None
    card_personalization: CardPersonalization = ...
    card_fulfillment_reason: Optional[StrictStr] = None
    __properties = ["shipping", "card_personalization", "card_fulfillment_reason"]

    @validator('card_fulfillment_reason')
    def card_fulfillment_reason_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('NEW', 'LOST_STOLEN', 'EXPIRED'):
            raise ValueError("must be one of enum values ('NEW', 'LOST_STOLEN', 'EXPIRED')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CardFulfillmentResponse:
        """Create an instance of CardFulfillmentResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of shipping
        if self.shipping:
            _dict['shipping'] = self.shipping.to_dict()
        # override the default output from pydantic by calling `to_dict()` of card_personalization
        if self.card_personalization:
            _dict['card_personalization'] = self.card_personalization.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CardFulfillmentResponse:
        """Create an instance of CardFulfillmentResponse from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return CardFulfillmentResponse.parse_obj(obj)

        _obj = CardFulfillmentResponse.parse_obj({
            "shipping": ShippingInformationResponse.from_dict(obj.get("shipping")) if obj.get("shipping") is not None else None,
            "card_personalization": CardPersonalization.from_dict(obj.get("card_personalization")) if obj.get("card_personalization") is not None else None,
            "card_fulfillment_reason": obj.get("card_fulfillment_reason")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import List, Optional
from pydantic import BaseModel, StrictStr, conlist
from marqeta_client.models.address_response_model import AddressResponseModel
from marqeta_client.models.identification_response_model import IdentificationResponseModel

class BusinessProprietorResponse(BaseModel):
    """
    BusinessProprietorResponse
    """
    first_name: Optional[StrictStr] = None
    middle_name: Optional[StrictStr] = None
    last_name: Optional[StrictStr] = None
    alternative_names: Optional[StrictStr] = None
    title: Optional[StrictStr] = None
    home: Optional[AddressResponseModel] = None
    ssn: Optional[StrictStr] = None
    dob: Optional[datetime] = None
    phone: Optional[StrictStr] = None
    email: Optional[StrictStr] = None
    identifications: Optional[conlist(IdentificationResponseModel)] = None
    __properties = ["first_name", "middle_name", "last_name", "alternative_names", "title", "home", "ssn", "dob", "phone", "email", "identifications"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> BusinessProprietorResponse:
        """Create an instance of BusinessProprietorResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of home
        if self.home:
            _dict['home'] = self.home.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in identifications (list)
        _items = []
        if self.identifications:
            for _item in self.identifications:
                if _item:
                    _items.append(_item.to_dict())
            _dict['identifications'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> BusinessProprietorResponse:
        """Create an instance of BusinessProprietorResponse from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return BusinessProprietorResponse.parse_obj(obj)

        _obj = BusinessProprietorResponse.parse_obj({
            "first_name": obj.get("first_name"),
            "middle_name": obj.get("middle_name"),
            "last_name": obj.get("last_name"),
            "alternative_names": obj.get("alternative_names"),
            "title": obj.get("title"),
            "home": AddressResponseModel.from_dict(obj.get("home")) if obj.get("home") is not None else None,
            "ssn": obj.get("ssn"),
            "dob": obj.get("dob"),
            "phone": obj.get("phone"),
            "email": obj.get("email"),
            "identifications": [IdentificationResponseModel.from_dict(_item) for _item in obj.get("identifications")] if obj.get("identifications") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictStr
from marqeta_client.models.installment_payment import InstallmentPayment

class NetworkMetadata(BaseModel):
    """
    NetworkMetadata
    """
    product_id: Optional[StrictStr] = None
    program_id: Optional[StrictStr] = None
    spend_qualifier: Optional[StrictStr] = None
    surcharge_free_atm_network: Optional[StrictStr] = None
    account_identification_1: Optional[StrictStr] = None
    installment_payment: Optional[InstallmentPayment] = None
    __properties = ["product_id", "program_id", "spend_qualifier", "surcharge_free_atm_network", "account_identification_1", "installment_payment"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> NetworkMetadata:
        """Create an instance of NetworkMetadata from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of installment_payment
        if self.installment_payment:
            _dict['installment_payment'] = self.installment_payment.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> NetworkMetadata:
        """Create an instance of NetworkMetadata from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return NetworkMetadata.parse_obj(obj)

        _obj = NetworkMetadata.parse_obj({
            "product_id": obj.get("product_id"),
            "program_id": obj.get("program_id"),
            "spend_qualifier": obj.get("spend_qualifier"),
            "surcharge_free_atm_network": obj.get("surcharge_free_atm_network"),
            "account_identification_1": obj.get("account_identification_1"),
            "installment_payment": InstallmentPayment.from_dict(obj.get("installment_payment")) if obj.get("installment_payment") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, StrictStr
from marqeta_client.models.address_verification import AddressVerification
from marqeta_client.models.device import Device
from marqeta_client.models.digital_wallet_token_metadata import DigitalWalletTokenMetadata
from marqeta_client.models.token_service_provider import TokenServiceProvider
from marqeta_client.models.user_card_holder_response import UserCardHolderResponse
from marqeta_client.models.wallet_provider_profile import WalletProviderProfile

class DigitalWalletToken(BaseModel):
    """
    DigitalWalletToken
    """
    token: Optional[StrictStr] = None
    card_token: Optional[StrictStr] = None
    state: Optional[StrictStr] = None
    state_reason: Optional[StrictStr] = None
    fulfillment_status: Optional[StrictStr] = None
    issuer_eligibility_decision: Optional[StrictStr] = None
    created_time: Optional[datetime] = None
    last_modified_time: Optional[datetime] = None
    token_service_provider: Optional[TokenServiceProvider] = None
    device: Optional[Device] = None
    wallet_provider_profile: Optional[WalletProviderProfile] = None
    address_verification: Optional[AddressVerification] = None
    user: Optional[UserCardHolderResponse] = None
    metadata: Optional[DigitalWalletTokenMetadata] = None
    __properties = ["token", "card_token", "state", "state_reason", "fulfillment_status", "issuer_eligibility_decision", "created_time", "last_modified_time", "token_service_provider", "device", "wallet_provider_profile", "address_verification", "user", "metadata"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> DigitalWalletToken:
        """Create an instance of DigitalWalletToken from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of token_service_provider
        if self.token_service_provider:
            _dict['token_service_provider'] = self.token_service_provider.to_dict()
        # override the default output from pydantic by calling `to_dict()` of device
        if self.device:
            _dict['device'] = self.device.to_dict()
        # override the default output from pydantic by calling `to_dict()` of wallet_provider_profile
        if self.wallet_provider_profile:
            _dict['wallet_provider_profile'] = self.wallet_provider_profile.to_dict()
        # override the default output from pydantic by calling `to_dict()` of address_verification
        if self.address_verification:
            _dict['address_verification'] = self.address_verification.to_dict()
        # override the default output from pydantic by calling `to_dict()` of user
        if self.user:
            _dict['user'] = self.user.to_dict()
        # override the default output from pydantic by calling `to_dict()` of metadata
        if self.metadata:
            _dict['metadata'] = self.metadata.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> DigitalWalletToken:
        """Create an instance of DigitalWalletToken from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return DigitalWalletToken.parse_obj(obj)

        _obj = DigitalWalletToken.parse_obj({
            "token": obj.get("token"),
            "card_token": obj.get("card_token"),
            "state": obj.get("state"),
            "state_reason": obj.get("state_reason"),
            "fulfillment_status": obj.get("fulfillment_status"),
            "issuer_eligibility_decision": obj.get("issuer_eligibility_decision"),
            "created_time": obj.get("created_time"),
            "last_modified_time": obj.get("last_modified_time"),
            "token_service_provider": TokenServiceProvider.from_dict(obj.get("token_service_provider")) if obj.get("token_service_provider") is not None else None,
            "device": Device.from_dict(obj.get("device")) if obj.get("device") is not None else None,
            "wallet_provider_profile": WalletProviderProfile.from_dict(obj.get("wallet_provider_profile")) if obj.get("wallet_provider_profile") is not None else None,
            "address_verification": AddressVerification.from_dict(obj.get("address_verification")) if obj.get("address_verification") is not None else None,
            "user": UserCardHolderResponse.from_dict(obj.get("user")) if obj.get("user") is not None else None,
            "metadata": DigitalWalletTokenMetadata.from_dict(obj.get("metadata")) if obj.get("metadata") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Dict, List, Optional, Union
from pydantic import BaseModel, Field, StrictBool, StrictFloat, StrictInt, StrictStr, conlist, constr, validator
from marqeta_client.models.account_funding import AccountFunding
from marqeta_client.models.acquirer import Acquirer
from marqeta_client.models.address_verification_model import AddressVerificationModel
from marqeta_client.models.atc_information_model import ATCInformationModel
from marqeta_client.models.auto_reload_model import AutoReloadModel
from marqeta_client.models.business_metadata import BusinessMetadata
from marqeta_client.models.card_response import CardResponse
from marqeta_client.models.card_security_code_verification import CardSecurityCodeVerification
from marqeta_client.models.cardholder_authentication_data import CardholderAuthenticationData
from marqeta_client.models.cardholder_balance import CardholderBalance
from marqeta_client.models.cardholder_metadata import CardholderMetadata
from marqeta_client.models.chargeback_response import ChargebackResponse
from marqeta_client.models.currency_conversion import CurrencyConversion
from marqeta_client.models.deposit_deposit_response import DepositDepositResponse
from marqeta_client.models.digital_wallet_token import DigitalWalletToken
from marqeta_client.models.dispute_model import DisputeModel
from marqeta_client.models.fee import Fee
from marqeta_client.models.fee_transfer_response import FeeTransferResponse
from marqeta_client.models.fraud_view import FraudView
from marqeta_client.models.gpa_response import GpaResponse
from marqeta_client.models.gpa_returns import GpaReturns
from marqeta_client.models.merchant_response_model import MerchantResponseModel
from marqeta_client.models.msa_order_response import MsaOrderResponse
from marqeta_client.models.msa_returns import MsaReturns
from marqeta_client.models.network_fee_model import NetworkFeeModel
from marqeta_client.models.network_metadata import NetworkMetadata
from marqeta_client.models.offer_order_response import OfferOrderResponse
from marqeta_client.models.original_credit import OriginalCredit
from marqeta_client.models.peer_transfer_response import PeerTransferResponse
from marqeta_client.models.pos import Pos
from marqeta_client.models.preceding_transaction import PrecedingTransaction
from marqeta_client.models.program import Program
from marqeta_client.models.program_transfer_response import ProgramTransferResponse
from marqeta_client.models.pull_from_card_transfer_response import PullFromCardTransferResponse
from marqeta_client.models.real_time_fee_group import RealTimeFeeGroup
from marqeta_client.models.response import Response
from marqeta_client.models.store_response_model import StoreResponseModel
from marqeta_client.models.transaction_card_acceptor import TransactionCardAcceptor
from marqeta_client.models.transaction_metadata import TransactionMetadata
from marqeta_client.models.user_card_holder_response import UserCardHolderResponse

class TransactionModel(BaseModel):
    """
    TransactionModel
    """
    identifier: Optional[StrictStr] = None
    token: constr(strict=True, max_length=36, min_length=1) = ...
    user_token: Optional[constr(strict=True, max_length=36, min_length=0)] = None
    business_token: Optional[constr(strict=True, max_length=36, min_length=0)] = None
    acting_user_token: constr(strict=True, max_length=36, min_length=0) = ...
    card_token: Optional[constr(strict=True, max_length=36, min_length=0)] = None
    card_product_token: Optional[constr(strict=True, max_length=36, min_length=0)] = None
    is_preauthorization: Optional[StrictBool] = False
    type: StrictStr = ...
    state: StrictStr = ...
    duration: Optional[StrictInt] = None
    created_time: Optional[datetime] = None
    user_transaction_time: Optional[datetime] = None
    settlement_date: Optional[datetime] = None
    request_amount: Optional[Union[StrictFloat, StrictInt]] = None
    amount: Union[StrictFloat, StrictInt] = ...
    cash_back_amount: Optional[Union[StrictFloat, StrictInt]] = None
    currency_conversion: Optional[CurrencyConversion] = None
    issuer_interchange_amount: Optional[Union[StrictFloat, StrictInt]] = None
    currency_code: Optional[StrictStr] = None
    approval_code: Optional[StrictStr] = None
    response: Optional[Response] = None
    preceding_related_transaction_token: Optional[StrictStr] = None
    preceding_transaction: Optional[PrecedingTransaction] = None
    amount_to_be_released: Optional[Union[StrictFloat, StrictInt]] = None
    incremental_authorization_transaction_tokens: Optional[conlist(StrictStr)] = None
    merchant: Optional[MerchantResponseModel] = None
    store: Optional[StoreResponseModel] = None
    card_acceptor: Optional[TransactionCardAcceptor] = None
    gpa: Optional[CardholderBalance] = None
    card: Optional[CardResponse] = None
    gpa_order_unload: Optional[GpaReturns] = None
    gpa_order: Optional[GpaResponse] = None
    program_transfer: Optional[ProgramTransferResponse] = None
    fee_transfer: Optional[FeeTransferResponse] = None
    peer_transfer: Optional[PeerTransferResponse] = None
    msa_orders: Optional[conlist(MsaOrderResponse)] = None
    msa_order_unload: Optional[MsaReturns] = None
    offer_orders: Optional[conlist(OfferOrderResponse)] = None
    auto_reload: Optional[AutoReloadModel] = None
    direct_deposit: Optional[DepositDepositResponse] = None
    pull_from_card: Optional[PullFromCardTransferResponse] = None
    polarity: Optional[StrictStr] = None
    real_time_fee_group: Optional[RealTimeFeeGroup] = None
    fee: Optional[Fee] = None
    chargeback: Optional[ChargebackResponse] = None
    dispute: Optional[DisputeModel] = None
    network: Optional[StrictStr] = None
    subnetwork: Optional[StrictStr] = None
    network_metadata: Optional[NetworkMetadata] = None
    acquirer_fee_amount: Optional[Union[StrictFloat, StrictInt]] = None
    fees: Optional[conlist(NetworkFeeModel)] = None
    digital_wallet_token: Optional[DigitalWalletToken] = None
    user: Optional[CardholderMetadata] = None
    business: Optional[BusinessMetadata] = None
    acquirer: Optional[Acquirer] = None
    fraud: Optional[FraudView] = None
    pos: Optional[Pos] = None
    address_verification: Optional[AddressVerificationModel] = None
    card_security_code_verification: Optional[CardSecurityCodeVerification] = None
    transaction_metadata: Optional[TransactionMetadata] = None
    original_credit: Optional[OriginalCredit] = None
    account_funding: Optional[AccountFunding] = None
    card_holder_model: Optional[UserCardHolderResponse] = None
    standin_approved_by: Optional[StrictStr] = None
    standin_by: Optional[StrictStr] = None
    standin_reason: Optional[StrictStr] = None
    network_reference_id: Optional[StrictStr] = None
    acquirer_reference_id: Optional[StrictStr] = None
    cardholder_authentication_data: Optional[CardholderAuthenticationData] = None
    transaction_attributes: Optional[Dict[str, StrictStr]] = None
    clearing_record_sequence_number: Optional[StrictStr] = None
    issuer_received_time: Optional[StrictStr] = None
    issuer_payment_node: Optional[StrictStr] = None
    program: Optional[Program] = None
    batch_number: Optional[StrictStr] = None
    from_account: Optional[StrictStr] = None
    multi_clearing_sequence_number: Optional[StrictStr] = None
    multi_clearing_sequence_count: Optional[StrictStr] = None
    isa_indicator: Optional[StrictStr] = Field(None, alias="isaIndicator")
    enhanced_data_token: Optional[StrictStr] = None
    advice_reason_code: Optional[StrictStr] = None
    advice_reason_details: Optional[StrictStr] = None
    bank_transfer_token: Optional[StrictStr] = None
    interchange_rate_descriptor: Optional[StrictStr] = None
    real_time_fee_type: Optional[StrictStr] = None
    atc_information: Optional[ATCInformationModel] = None
    __properties = ["identifier", "token", "user_token", "business_token", "acting_user_token", "card_token", "card_product_token", "is_preauthorization", "type", "state", "duration", "created_time", "user_transaction_time", "settlement_date", "request_amount", "amount", "cash_back_amount", "currency_conversion", "issuer_interchange_amount", "currency_code", "approval_code", "response", "preceding_related_transaction_token", "preceding_transaction", "amount_to_be_released", "incremental_authorization_transaction_tokens", "merchant", "store", "card_acceptor", "gpa", "card", "gpa_order_unload", "gpa_order", "program_transfer", "fee_transfer", "peer_transfer", "msa_orders", "msa_order_unload", "offer_orders", "auto_reload", "direct_deposit", "pull_from_card", "polarity", "real_time_fee_group", "fee", "chargeback", "dispute", "network", "subnetwork", "network_metadata", "acquirer_fee_amount", "fees", "digital_wallet_token", "user", "business", "acquirer", "fraud", "pos", "address_verification", "card_security_code_verification", "transaction_metadata", "original_credit", "account_funding", "card_holder_model", "standin_approved_by", "standin_by", "standin_reason", "network_reference_id", "acquirer_reference_id", "cardholder_authentication_data", "transaction_attributes", "clearing_record_sequence_number", "issuer_received_time", "issuer_payment_node", "program", "batch_number", "from_account", "multi_clearing_sequence_number", "multi_clearing_sequence_count", "isaIndicator", "enhanced_data_token", "advice_reason_code", "advice_reason_details", "bank_transfer_token", "interchange_rate_descriptor", "real_time_fee_type", "atc_information"]

    @validator('type')
    def type_validate_enum(cls, v):
        if v not in ('gpa.credit', 'gpa.credit.pending', 'gpa.credit.pending.reversal', 'gpa.credit.reversal', 'gpa.credit.networkload', 'gpa.credit.networkload.reversal', 'gpa.debit.networkload', 'gpa.debit', 'gpa.debit.pending', 'gpa.debit.pending.reversal', 'gpa.grant', 'gpa.credit.issueroperator', 'gpa.debit.issueroperator', 'gpa.credit.chargeback', 'gpa.credit.chargeback.reversal', 'gpa.credit.billpayment', 'gpa.credit.authorization.billpayment', 'gpa.credit.authorization.billpayment.reversal', 'msa.credit.pending', 'msa.credit.pending.reversal', 'msa.credit.reversal', 'msa.credit', 'msa.debit.pending', 'msa.debit.pending.reversal', 'msa.debit', 'msa.credit.chargeback', 'msa.credit.chargeback.reversal', 'authorization', 'authorization.advice', 'authorization.reversal', 'authorization.clearing', 'authorization.reversal.issuerexpiration', 'dispute.credit', 'dispute.debit', 'authorization.clearing.chargeback', 'authorization.clearing.chargeback.reversal', 'refund', 'pindebit.atm.withdrawal', 'pindebit.balanceinquiry', 'pindebit.cashback', 'pindebit', 'programreserve.credit', 'programreserve.debit', 'fee.charge.pending', 'fee.charge', 'fee.charge.pending.refund', 'funds.expire', 'reward.earn', 'transfer.peer', 'transfer.fee', 'account.funding.authorization', 'account.funding.authorization.reversal', 'account.funding.authorization.clearing', 'account.funding.auth_plus_capture', 'account.funding.auth_plus_capture.reversal', 'account.credit', 'account.debit', 'balanceinquiry', 'authorization.atm.withdrawal', 'authorization.clearing.atm.withdrawal', 'authorization.cashback', 'authorization.clearing.cashback', 'transfer.program', 'authorization.quasi.cash', 'authorization.clearing.quasi.cash', 'authorization.incremental', 'gpa.credit.authorization', 'gpa.credit.authorization.reversal', 'gpa.debit.authorization', 'gpa.debit.reversal', 'original.credit.authorization', 'original.credit.authorization.reversal', 'original.credit.authorization.clearing', 'original.credit.auth_plus_capture', 'original.credit.auth_plus_capture.reversal', 'refund.authorization', 'refund.authorization.advice', 'refund.authorization.clearing', 'refund.authorization.reversal', 'token.activation-request', 'token.advice', 'pindebit.authorization', 'pindebit.authorization.clearing', 'pindebit.authorization.reversal', 'pindebit.authorization.reversal.issuerexpiration', 'authorization.standin', 'authorization.clearing.chargeback.completed', 'authorization.clearing.chargeback.provisional.credit', 'authorization.clearing.chargeback.provisional.debit', 'authorization.clearing.chargeback.writeoff', 'directdeposit.credit', 'directdeposit.credit.pending', 'directdeposit.credit.reject', 'directdeposit.credit.pending.reversal', 'directdeposit.credit.reversal', 'directdeposit.debit', 'directdeposit.debit.pending', 'directdeposit.debit.reject', 'directdeposit.debit.reversal', 'directdeposit.debit.pending.reversal', 'fee.charge.reversal', 'pindebit.chargeback', 'pindebit.chargeback.completed', 'pindebit.chargeback.provisional.credit', 'pindebit.chargeback.provisional.debit', 'pindebit.chargeback.reversal', 'pindebit.chargeback.writeoff', 'pindebit.credit.adjustment', 'pindebit.quasicash', 'pindebit.quasi.cash', 'pindebit.refund', 'pindebit.refund.reversal', 'pindebit.reversal', 'pindebit.transfer', 'pushtocard.debit', 'pushtocard.reversal', 'credit.adjustment', 'debit.adjustment', 'unknown'):
            raise ValueError("must be one of enum values ('gpa.credit', 'gpa.credit.pending', 'gpa.credit.pending.reversal', 'gpa.credit.reversal', 'gpa.credit.networkload', 'gpa.credit.networkload.reversal', 'gpa.debit.networkload', 'gpa.debit', 'gpa.debit.pending', 'gpa.debit.pending.reversal', 'gpa.grant', 'gpa.credit.issueroperator', 'gpa.debit.issueroperator', 'gpa.credit.chargeback', 'gpa.credit.chargeback.reversal', 'gpa.credit.billpayment', 'gpa.credit.authorization.billpayment', 'gpa.credit.authorization.billpayment.reversal', 'msa.credit.pending', 'msa.credit.pending.reversal', 'msa.credit.reversal', 'msa.credit', 'msa.debit.pending', 'msa.debit.pending.reversal', 'msa.debit', 'msa.credit.chargeback', 'msa.credit.chargeback.reversal', 'authorization', 'authorization.advice', 'authorization.reversal', 'authorization.clearing', 'authorization.reversal.issuerexpiration', 'dispute.credit', 'dispute.debit', 'authorization.clearing.chargeback', 'authorization.clearing.chargeback.reversal', 'refund', 'pindebit.atm.withdrawal', 'pindebit.balanceinquiry', 'pindebit.cashback', 'pindebit', 'programreserve.credit', 'programreserve.debit', 'fee.charge.pending', 'fee.charge', 'fee.charge.pending.refund', 'funds.expire', 'reward.earn', 'transfer.peer', 'transfer.fee', 'account.funding.authorization', 'account.funding.authorization.reversal', 'account.funding.authorization.clearing', 'account.funding.auth_plus_capture', 'account.funding.auth_plus_capture.reversal', 'account.credit', 'account.debit', 'balanceinquiry', 'authorization.atm.withdrawal', 'authorization.clearing.atm.withdrawal', 'authorization.cashback', 'authorization.clearing.cashback', 'transfer.program', 'authorization.quasi.cash', 'authorization.clearing.quasi.cash', 'authorization.incremental', 'gpa.credit.authorization', 'gpa.credit.authorization.reversal', 'gpa.debit.authorization', 'gpa.debit.reversal', 'original.credit.authorization', 'original.credit.authorization.reversal', 'original.credit.authorization.clearing', 'original.credit.auth_plus_capture', 'original.credit.auth_plus_capture.reversal', 'refund.authorization', 'refund.authorization.advice', 'refund.authorization.clearing', 'refund.authorization.reversal', 'token.activation-request', 'token.advice', 'pindebit.authorization', 'pindebit.authorization.clearing', 'pindebit.authorization.reversal', 'pindebit.authorization.reversal.issuerexpiration', 'authorization.standin', 'authorization.clearing.chargeback.completed', 'authorization.clearing.chargeback.provisional.credit', 'authorization.clearing.chargeback.provisional.debit', 'authorization.clearing.chargeback.writeoff', 'directdeposit.credit', 'directdeposit.credit.pending', 'directdeposit.credit.reject', 'directdeposit.credit.pending.reversal', 'directdeposit.credit.reversal', 'directdeposit.debit', 'directdeposit.debit.pending', 'directdeposit.debit.reject', 'directdeposit.debit.reversal', 'directdeposit.debit.pending.reversal', 'fee.charge.reversal', 'pindebit.chargeback', 'pindebit.chargeback.completed', 'pindebit.chargeback.provisional.credit', 'pindebit.chargeback.provisional.debit', 'pindebit.chargeback.reversal', 'pindebit.chargeback.writeoff', 'pindebit.credit.adjustment', 'pindebit.quasicash', 'pindebit.quasi.cash', 'pindebit.refund', 'pindebit.refund.reversal', 'pindebit.reversal', 'pindebit.transfer', 'pushtocard.debit', 'pushtocard.reversal', 'credit.adjustment', 'debit.adjustment', 'unknown')")
        return v

    @validator('state')
    def state_validate_enum(cls, v):
        if v not in ('PENDING', 'CLEARED', 'COMPLETION', 'DECLINED', 'ERROR'):
            raise ValueError("must be one of enum values ('PENDING', 'CLEARED', 'COMPLETION', 'DECLINED', 'ERROR')")
        return v

    @validator('polarity')
    def polarity_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('CREDIT', 'DEBIT', 'PENDING_CREDIT', 'PENDING_DEBIT'):
            raise ValueError("must be one of enum values ('CREDIT', 'DEBIT', 'PENDING_CREDIT', 'PENDING_DEBIT')")
        return v

    @validator('isa_indicator')
    def isa_indicator_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('MULTI_CURRENCY', 'SINGLE_CURRENCY', 'REBATE_CANCELLED', 'MULTI_CURRENCY_NON_US_COUNTRIES', 'SINGLE_CURRENCY_PAID_BY_ISSUER', 'NO_CHARGE_ASSESSED'):
            raise ValueError("must be one of enum values ('MULTI_CURRENCY', 'SINGLE_CURRENCY', 'REBATE_CANCELLED', 'MULTI_CURRENCY_NON_US_COUNTRIES', 'SINGLE_CURRENCY_PAID_BY_ISSUER', 'NO_CHARGE_ASSESSED')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TransactionModel:
        """Create an instance of TransactionModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "token",
                            "type",
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of currency_conversion
        if self.currency_conversion:
            _dict['currency_conversion'] = self.currency_conversion.to_dict()
        # override the default output from pydantic by calling `to_dict()` of response
        if self.response:
            _dict['response'] = self.response.to_dict()
        # override the default output from pydantic by calling `to_dict()` of preceding_transaction
        if self.preceding_transaction:
            _dict['preceding_transaction'] = self.preceding_transaction.to_dict()
        # override the default output from pydantic by calling `to_dict()` of merchant
        if self.merchant:
            _dict['merchant'] = self.merchant.to_dict()
        # override the default output from pydantic by calling `to_dict()` of store
        if self.store:
            _dict['store'] = self.store.to_dict()
        # override the default output from pydantic by calling `to_dict()` of card_acceptor
        if self.card_acceptor:
            _dict['card_acceptor'] = self.card_acceptor.to_dict()
        # override the default output from pydantic by calling `to_dict()` of gpa
        if self.gpa:
            _dict['gpa'] = self.gpa.to_dict()
        # override the default output from pydantic by calling `to_dict()` of card
        if self.card:
            _dict['card'] = self.card.to_dict()
        # override the default output from pydantic by calling `to_dict()` of gpa_order_unload
        if self.gpa_order_unload:
            _dict['gpa_order_unload'] = self.gpa_order_unload.to_dict()
        # override the default output from pydantic by calling `to_dict()` of gpa_order
        if self.gpa_order:
            _dict['gpa_order'] = self.gpa_order.to_dict()
        # override the default output from pydantic by calling `to_dict()` of program_transfer
        if self.program_transfer:
            _dict['program_transfer'] = self.program_transfer.to_dict()
        # override the default output from pydantic by calling `to_dict()` of fee_transfer
        if self.fee_transfer:
            _dict['fee_transfer'] = self.fee_transfer.to_dict()
        # override the default output from pydantic by calling `to_dict()` of peer_transfer
        if self.peer_transfer:
            _dict['peer_transfer'] = self.peer_transfer.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in msa_orders (list)
        _items = []
        if self.msa_orders:
            for _item in self.msa_orders:
                if _item:
                    _items.append(_item.to_dict())
            _dict['msa_orders'] = _items
        # override the default output from pydantic by calling `to_dict()` of msa_order_unload
        if self.msa_order_unload:
            _dict['msa_order_unload'] = self.msa_order_unload.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in offer_orders (list)
        _items = []
        if self.offer_orders:
            for _item in self.offer_orders:
                if _item:
                    _items.append(_item.to_dict())
            _dict['offer_orders'] = _items
        # override the default output from pydantic by calling `to_dict()` of auto_reload
        if self.auto_reload:
            _dict['auto_reload'] = self.auto_reload.to_dict()
        # override the default output from pydantic by calling `to_dict()` of direct_deposit
        if self.direct_deposit:
            _dict['direct_deposit'] = self.direct_deposit.to_dict()
        # override the default output from pydantic by calling `to_dict()` of pull_from_card
        if self.pull_from_card:
            _dict['pull_from_card'] = self.pull_from_card.to_dict()
        # override the default output from pydantic by calling `to_dict()` of real_time_fee_group
        if self.real_time_fee_group:
            _dict['real_time_fee_group'] = self.real_time_fee_group.to_dict()
        # override the default output from pydantic by calling `to_dict()` of fee
        if self.fee:
            _dict['fee'] = self.fee.to_dict()
        # override the default output from pydantic by calling `to_dict()` of chargeback
        if self.chargeback:
            _dict['chargeback'] = self.chargeback.to_dict()
        # override the default output from pydantic by calling `to_dict()` of dispute
        if self.dispute:
            _dict['dispute'] = self.dispute.to_dict()
        # override the default output from pydantic by calling `to_dict()` of network_metadata
        if self.network_metadata:
            _dict['network_metadata'] = self.network_metadata.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in fees (list)
        _items = []
        if self.fees:
            for _item in self.fees:
                if _item:
                    _items.append(_item.to_dict())
            _dict['fees'] = _items
        # override the default output from pydantic by calling `to_dict()` of digital_wallet_token
        if self.digital_wallet_token:
            _dict['digital_wallet_token'] = self.digital_wallet_token.to_dict()
        # override the default output from pydantic by calling `to_dict()` of user
        if self.user:
            _dict['user'] = self.user.to_dict()
        # override the default output from pydantic by calling `to_dict()` of business
        if self.business:
            _dict['business'] = self.business.to_dict()
        # override the default output from pydantic by calling `to_dict()` of acquirer
        if self.acquirer:
            _dict['acquirer'] = self.acquirer.to_dict()
        # override the default output from pydantic by calling `to_dict()` of fraud
        if self.fraud:
            _dict['fraud'] = self.fraud.to_dict()
        # override the default output from pydantic by calling `to_dict()` of pos
        if self.pos:
            _dict['pos'] = self.pos.to_dict()
        # override the default output from pydantic by calling `to_dict()` of address_verification
        if self.address_verification:
            _dict['address_verification'] = self.address_verification.to_dict()
        # override the default output from pydantic by calling `to_dict()` of card_security_code_verification
        if self.card_security_code_verification:
            _dict['card_security_code_verification'] = self.card_security_code_verification.to_dict()
        # override the default output from pydantic by calling `to_dict()` of transaction_metadata
        if self.transaction_metadata:
            _dict['transaction_metadata'] = self.transaction_metadata.to_dict()
        # override the default output from pydantic by calling `to_dict()` of original_credit
        if self.original_credit:
            _dict['original_credit'] = self.original_credit.to_dict()
        # override the default output from pydantic by calling `to_dict()` of account_funding
        if self.account_funding:
            _dict['account_funding'] = self.account_funding.to_dict()
        # override the default output from pydantic by calling `to_dict()` of card_holder_model
        if self.card_holder_model:
            _dict['card_holder_model'] = self.card_holder_model.to_dict()
        # override the default output from pydantic by calling `to_dict()` of cardholder_authentication_data
        if self.cardholder_authentication_data:
            _dict['cardholder_authentication_data'] = self.cardholder_authentication_data.to_dict()
        # override the default output from pydantic by calling `to_dict()` of program
        if self.program:
            _dict['program'] = self.program.to_dict()
        # override the default output from pydantic by calling `to_dict()` of atc_information
        if self.atc_information:
            _dict['atc_information'] = self.atc_information.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TransactionModel:
        """Create an instance of TransactionModel from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return TransactionModel.parse_obj(obj)

        _obj = TransactionModel.parse_obj({
            "identifier": obj.get("identifier"),
            "token": obj.get("token"),
            "user_token": obj.get("user_token"),
            "business_token": obj.get("business_token"),
            "acting_user_token": obj.get("acting_user_token"),
            "card_token": obj.get("card_token"),
            "card_product_token": obj.get("card_product_token"),
            "is_preauthorization": obj.get("is_preauthorization") if obj.get("is_preauthorization") is not None else False,
            "type": obj.get("type"),
            "state": obj.get("state"),
            "duration": obj.get("duration"),
            "created_time": obj.get("created_time"),
            "user_transaction_time": obj.get("user_transaction_time"),
            "settlement_date": obj.get("settlement_date"),
            "request_amount": obj.get("request_amount"),
            "amount": obj.get("amount"),
            "cash_back_amount": obj.get("cash_back_amount"),
            "currency_conversion": CurrencyConversion.from_dict(obj.get("currency_conversion")) if obj.get("currency_conversion") is not None else None,
            "issuer_interchange_amount": obj.get("issuer_interchange_amount"),
            "currency_code": obj.get("currency_code"),
            "approval_code": obj.get("approval_code"),
            "response": Response.from_dict(obj.get("response")) if obj.get("response") is not None else None,
            "preceding_related_transaction_token": obj.get("preceding_related_transaction_token"),
            "preceding_transaction": PrecedingTransaction.from_dict(obj.get("preceding_transaction")) if obj.get("preceding_transaction") is not None else None,
            "amount_to_be_released": obj.get("amount_to_be_released"),
            "incremental_authorization_transaction_tokens": obj.get("incremental_authorization_transaction_tokens"),
            "merchant": MerchantResponseModel.from_dict(obj.get("merchant")) if obj.get("merchant") is not None else None,
            "store": StoreResponseModel.from_dict(obj.get("store")) if obj.get("store") is not None else None,
            "card_acceptor": TransactionCardAcceptor.from_dict(obj.get("card_acceptor")) if obj.get("card_acceptor") is not None else None,
            "gpa": CardholderBalance.from_dict(obj.get("gpa")) if obj.get("gpa") is not None else None,
            "card": CardResponse.from_dict(obj.get("card")) if obj.get("card") is not None else None,
            "gpa_order_unload": GpaReturns.from_dict(obj.get("gpa_order_unload")) if obj.get("gpa_order_unload") is not None else None,
            "gpa_order": GpaResponse.from_dict(obj.get("gpa_order")) if obj.get("gpa_order") is not None else None,
            "program_transfer": ProgramTransferResponse.from_dict(obj.get("program_transfer")) if obj.get("program_transfer") is not None else None,
            "fee_transfer": FeeTransferResponse.from_dict(obj.get("fee_transfer")) if obj.get("fee_transfer") is not None else None,
            "peer_transfer": PeerTransferResponse.from_dict(obj.get("peer_transfer")) if obj.get("peer_transfer") is not None else None,
            "msa_orders": [MsaOrderResponse.from_dict(_item) for _item in obj.get("msa_orders")] if obj.get("msa_orders") is not None else None,
            "msa_order_unload": MsaReturns.from_dict(obj.get("msa_order_unload")) if obj.get("msa_order_unload") is not None else None,
            "offer_orders": [OfferOrderResponse.from_dict(_item) for _item in obj.get("offer_orders")] if obj.get("offer_orders") is not None else None,
            "auto_reload": AutoReloadModel.from_dict(obj.get("auto_reload")) if obj.get("auto_reload") is not None else None,
            "direct_deposit": DepositDepositResponse.from_dict(obj.get("direct_deposit")) if obj.get("direct_deposit") is not None else None,
            "pull_from_card": PullFromCardTransferResponse.from_dict(obj.get("pull_from_card")) if obj.get("pull_from_card") is not None else None,
            "polarity": obj.get("polarity"),
            "real_time_fee_group": RealTimeFeeGroup.from_dict(obj.get("real_time_fee_group")) if obj.get("real_time_fee_group") is not None else None,
            "fee": Fee.from_dict(obj.get("fee")) if obj.get("fee") is not None else None,
            "chargeback": ChargebackResponse.from_dict(obj.get("chargeback")) if obj.get("chargeback") is not None else None,
            "dispute": DisputeModel.from_dict(obj.get("dispute")) if obj.get("dispute") is not None else None,
            "network": obj.get("network"),
            "subnetwork": obj.get("subnetwork"),
            "network_metadata": NetworkMetadata.from_dict(obj.get("network_metadata")) if obj.get("network_metadata") is not None else None,
            "acquirer_fee_amount": obj.get("acquirer_fee_amount"),
            "fees": [NetworkFeeModel.from_dict(_item) for _item in obj.get("fees")] if obj.get("fees") is not None else None,
            "digital_wallet_token": DigitalWalletToken.from_dict(obj.get("digital_wallet_token")) if obj.get("digital_wallet_token") is not None else None,
            "user": CardholderMetadata.from_dict(obj.get("user")) if obj.get("user") is not None else None,
            "business": BusinessMetadata.from_dict(obj.get("business")) if obj.get("business") is not None else None,
            "acquirer": Acquirer.from_dict(obj.get("acquirer")) if obj.get("acquirer") is not None else None,
            "fraud": FraudView.from_dict(obj.get("fraud")) if obj.get("fraud") is not None else None,
            "pos": Pos.from_dict(obj.get("pos")) if obj.get("pos") is not None else None,
            "address_verification": AddressVerificationModel.from_dict(obj.get("address_verification")) if obj.get("address_verification") is not None else None,
            "card_security_code_verification": CardSecurityCodeVerification.from_dict(obj.get("card_security_code_verification")) if obj.get("card_security_code_verification") is not None else None,
            "transaction_metadata": TransactionMetadata.from_dict(obj.get("transaction_metadata")) if obj.get("transaction_metadata") is not None else None,
            "original_credit": OriginalCredit.from_dict(obj.get("original_credit")) if obj.get("original_credit") is not None else None,
            "account_funding": AccountFunding.from_dict(obj.get("account_funding")) if obj.get("account_funding") is not None else None,
            "card_holder_model": UserCardHolderResponse.from_dict(obj.get("card_holder_model")) if obj.get("card_holder_model") is not None else None,
            "standin_approved_by": obj.get("standin_approved_by"),
            "standin_by": obj.get("standin_by"),
            "standin_reason": obj.get("standin_reason"),
            "network_reference_id": obj.get("network_reference_id"),
            "acquirer_reference_id": obj.get("acquirer_reference_id"),
            "cardholder_authentication_data": CardholderAuthenticationData.from_dict(obj.get("cardholder_authentication_data")) if obj.get("cardholder_authentication_data") is not None else None,
            "transaction_attributes": obj.get("transaction_attributes"),
            "clearing_record_sequence_number": obj.get("clearing_record_sequence_number"),
            "issuer_received_time": obj.get("issuer_received_time"),
            "issuer_payment_node": obj.get("issuer_payment_node"),
            "program": Program.from_dict(obj.get("program")) if obj.get("program") is not None else None,
            "batch_number": obj.get("batch_number"),
            "from_account": obj.get("from_account"),
            "multi_clearing_sequence_number": obj.get("multi_clearing_sequence_number"),
            "multi_clearing_sequence_count": obj.get("multi_clearing_sequence_count"),
            "isa_indicator": obj.get("isaIndicator"),
            "enhanced_data_token": obj.get("enhanced_data_token"),
            "advice_reason_code": obj.get("advice_reason_code"),
            "advice_reason_details": obj.get("advice_reason_details"),
            "bank_transfer_token": obj.get("bank_transfer_token"),
            "interchange_rate_descriptor": obj.get("interchange_rate_descriptor"),
            "real_time_fee_type": obj.get("real_time_fee_type"),
            "atc_information": ATCInformationModel.from_dict(obj.get("atc_information")) if obj.get("atc_information") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictStr, constr, validator

class PinRevealRequest(BaseModel):
    """
    PinRevealRequest
    """
    control_token: constr(strict=True, max_length=36, min_length=1) = ...
    cardholder_verification_method: StrictStr = Field(..., description="Verification method required")
    __properties = ["control_token", "cardholder_verification_method"]

    @validator('cardholder_verification_method')
    def cardholder_verification_method_validate_enum(cls, v):
        if v not in ('BIOMETRIC_FACE', 'BIOMETRIC_FINGERPRINT', 'LOGIN', 'EXP_CVV', 'OTP_CVV', 'OTP', 'OTHER'):
            raise ValueError("must be one of enum values ('BIOMETRIC_FACE', 'BIOMETRIC_FINGERPRINT', 'LOGIN', 'EXP_CVV', 'OTP_CVV', 'OTP', 'OTHER')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PinRevealRequest:
        """Create an instance of PinRevealRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PinRevealRequest:
        """Create an instance of PinRevealRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return PinRevealRequest.parse_obj(obj)

        _obj = PinRevealRequest.parse_obj({
            "control_token": obj.get("control_token"),
            "cardholder_verification_method": obj.get("cardholder_verification_method")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr, validator

class ChargebackUpdateRequest(BaseModel):
    """
    ChargebackUpdateRequest
    """
    reason_description: Optional[StrictStr] = Field(None, description="Either 'reason_description' or 'reason_code' is required")
    reason_code: Optional[StrictStr] = Field(None, description="Either 'reason_code' or 'reason_description' is required")
    __properties = ["reason_description", "reason_code"]

    @validator('reason_description')
    def reason_description_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('SERVICE_NOT_PROVIDED_MERCHANDISE_NOT_RECEIVED', 'CANCELLED_RECURRING_TRANSACTION', 'NOT_AS_DESCRIBED_OR_DEFECTIVE_MERCHANDISE', 'FRAUD_MULTIPLE_TRANSACTIONS', 'FRAUD_TRANSACTION', 'NO_AUTHORIZATION', 'LATE_PRESENTMENT', 'TRANSACTION_NOT_RECOGNIZED', 'INCORRECT_CURRENCY', 'INCORRECT_TRANSACTION_CODE', 'INCORRECT_CURRENCY_OR_TRANSACTION_CODE', 'INCORRECT_TRANSACTION_AMOUNT', 'INCORRECT_ACCOUNT_NUMBER', 'INCORRECT_TRANSACTION_AMOUNT_OR_ACCOUNT_NUMBER', 'NOT_AUTHORIZED_CARD_PRESENT', 'NOT_AUTHORIZED_CARD_ABSENT', 'CREDIT_NOT_PROCESSED', 'NON_RECEIPT_OF_CASH_OR_LOAD_TRANSACTION_VALUE_AT_ATM', 'DUPLICATE_PROCESSING_OR_PAID_BY_OTHER_MEANS'):
            raise ValueError("must be one of enum values ('SERVICE_NOT_PROVIDED_MERCHANDISE_NOT_RECEIVED', 'CANCELLED_RECURRING_TRANSACTION', 'NOT_AS_DESCRIBED_OR_DEFECTIVE_MERCHANDISE', 'FRAUD_MULTIPLE_TRANSACTIONS', 'FRAUD_TRANSACTION', 'NO_AUTHORIZATION', 'LATE_PRESENTMENT', 'TRANSACTION_NOT_RECOGNIZED', 'INCORRECT_CURRENCY', 'INCORRECT_TRANSACTION_CODE', 'INCORRECT_CURRENCY_OR_TRANSACTION_CODE', 'INCORRECT_TRANSACTION_AMOUNT', 'INCORRECT_ACCOUNT_NUMBER', 'INCORRECT_TRANSACTION_AMOUNT_OR_ACCOUNT_NUMBER', 'NOT_AUTHORIZED_CARD_PRESENT', 'NOT_AUTHORIZED_CARD_ABSENT', 'CREDIT_NOT_PROCESSED', 'NON_RECEIPT_OF_CASH_OR_LOAD_TRANSACTION_VALUE_AT_ATM', 'DUPLICATE_PROCESSING_OR_PAID_BY_OTHER_MEANS')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ChargebackUpdateRequest:
        """Create an instance of ChargebackUpdateRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ChargebackUpdateRequest:
        """Create an instance of ChargebackUpdateRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return ChargebackUpdateRequest.parse_obj(obj)

        _obj = ChargebackUpdateRequest.parse_obj({
            "reason_description": obj.get("reason_description"),
            "reason_code": obj.get("reason_code")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Dict, List, Optional, Union
from pydantic import BaseModel, StrictStr, confloat, conint, conlist, constr, validator
from marqeta_client.models.cardholder_balance import CardholderBalance
from marqeta_client.models.jit_address_verification import JitAddressVerification

class JitFundingApi(BaseModel):
    """
    JitFundingApi
    """
    token: constr(strict=True, max_length=36, min_length=0) = ...
    method: StrictStr = ...
    user_token: constr(strict=True, max_length=36, min_length=0) = ...
    acting_user_token: Optional[constr(strict=True, max_length=36, min_length=0)] = None
    business_token: Optional[constr(strict=True, max_length=36, min_length=0)] = None
    amount: Union[confloat(ge=0, strict=True), conint(ge=0, strict=True)] = ...
    memo: Optional[constr(strict=True, max_length=99, min_length=0)] = None
    tags: Optional[constr(strict=True, max_length=255, min_length=0)] = None
    original_jit_funding_token: Optional[constr(strict=True, max_length=36, min_length=0)] = None
    incremental_authorization_jit_funding_tokens: Optional[conlist(StrictStr)] = None
    address_verification: Optional[JitAddressVerification] = None
    decline_reason: Optional[StrictStr] = None
    balances: Optional[Dict[str, CardholderBalance]] = None
    __properties = ["token", "method", "user_token", "acting_user_token", "business_token", "amount", "memo", "tags", "original_jit_funding_token", "incremental_authorization_jit_funding_tokens", "address_verification", "decline_reason", "balances"]

    @validator('method')
    def method_validate_enum(cls, v):
        if v not in ('pgfs.authorization', 'pgfs.balanceinquiry', 'pgfs.authorization.incremental', 'pgfs.authorization.capture', 'pgfs.authorization.reversal', 'pgfs.auth_plus_capture', 'pgfs.refund', 'pgfs.force_capture', 'pgfs.authorization.capture.chargeback', 'pgfs.authorization.capture.chargeback.reversal', 'pgfs.pindebit.chargeback', 'pgfs.pindebit.chargeback.reversal', 'pgfs.dispute.credit', 'pgfs.dispute.debit', 'pgfs.directdeposit.credit', 'pgfs.directdeposit.debit', 'pgfs.directdeposit.credit.reversal', 'pgfs.directdeposit.debit.reversal', 'pgfs.adjustment.credit', 'pgfs.adjustment.debit', 'pgfs.auth_plus_capture.standin', 'pgfs.authorization.standin', 'pgfs.network.load', 'pgfs.original.credit.authorization', 'pgfs.original.credit.auth_plus_capture', 'pgfs.refund.authorization', 'pgfs.refund.authorization.reversalpgfs.billpayment', 'pgfs.billpayment.capture', 'pgfs.billpayment.reversal', 'pgfs.authorization.account_verification'):
            raise ValueError("must be one of enum values ('pgfs.authorization', 'pgfs.balanceinquiry', 'pgfs.authorization.incremental', 'pgfs.authorization.capture', 'pgfs.authorization.reversal', 'pgfs.auth_plus_capture', 'pgfs.refund', 'pgfs.force_capture', 'pgfs.authorization.capture.chargeback', 'pgfs.authorization.capture.chargeback.reversal', 'pgfs.pindebit.chargeback', 'pgfs.pindebit.chargeback.reversal', 'pgfs.dispute.credit', 'pgfs.dispute.debit', 'pgfs.directdeposit.credit', 'pgfs.directdeposit.debit', 'pgfs.directdeposit.credit.reversal', 'pgfs.directdeposit.debit.reversal', 'pgfs.adjustment.credit', 'pgfs.adjustment.debit', 'pgfs.auth_plus_capture.standin', 'pgfs.authorization.standin', 'pgfs.network.load', 'pgfs.original.credit.authorization', 'pgfs.original.credit.auth_plus_capture', 'pgfs.refund.authorization', 'pgfs.refund.authorization.reversalpgfs.billpayment', 'pgfs.billpayment.capture', 'pgfs.billpayment.reversal', 'pgfs.authorization.account_verification')")
        return v

    @validator('decline_reason')
    def decline_reason_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('INVALID_AMOUNT', 'INSUFFICIENT_FUNDS', 'TRANSACTION_NOT_PERMITTED', 'SUSPECTED_FRAUD', 'AMOUNT_LIMIT_EXCEEDED', 'TRANSACTION_COUNT_LIMIT_EXCEEDED', 'DUPLICATE_TRANSACTION', 'INVALID_MERCHANT', 'INVALID_CARD', 'NO_CREDIT_ACCOUNT', 'EXPIRED_CARD', 'NO_CHECKING_ACCOUNT', 'NO_SAVINGS_ACCOUNT', 'STOP_PAYMENT', 'REVOCATION_AUTHORIZATION_ORDER', 'REVOCATION_ALL_AUTHORIZATION_ORDER', 'SOFT_DECLINE_AUTHENTICATION_REQUIRED', 'CLOSED_ACCOUNT', 'SOFT_DECLINE_PIN_REQUIRED', 'CARD_NOT_ACTIVE', 'CARDHOLDER_NOT_ACTIVE'):
            raise ValueError("must be one of enum values ('INVALID_AMOUNT', 'INSUFFICIENT_FUNDS', 'TRANSACTION_NOT_PERMITTED', 'SUSPECTED_FRAUD', 'AMOUNT_LIMIT_EXCEEDED', 'TRANSACTION_COUNT_LIMIT_EXCEEDED', 'DUPLICATE_TRANSACTION', 'INVALID_MERCHANT', 'INVALID_CARD', 'NO_CREDIT_ACCOUNT', 'EXPIRED_CARD', 'NO_CHECKING_ACCOUNT', 'NO_SAVINGS_ACCOUNT', 'STOP_PAYMENT', 'REVOCATION_AUTHORIZATION_ORDER', 'REVOCATION_ALL_AUTHORIZATION_ORDER', 'SOFT_DECLINE_AUTHENTICATION_REQUIRED', 'CLOSED_ACCOUNT', 'SOFT_DECLINE_PIN_REQUIRED', 'CARD_NOT_ACTIVE', 'CARDHOLDER_NOT_ACTIVE')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> JitFundingApi:
        """Create an instance of JitFundingApi from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of address_verification
        if self.address_verification:
            _dict['address_verification'] = self.address_verification.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each value in balances (dict)
        _field_dict = {}
        if self.balances:
            for _key in self.balances:
                if self.balances[_key]:
                    _field_dict[_key] = self.balances[_key].to_dict()
            _dict['balances'] = _field_dict
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> JitFundingApi:
        """Create an instance of JitFundingApi from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return JitFundingApi.parse_obj(obj)

        _obj = JitFundingApi.parse_obj({
            "token": obj.get("token"),
            "method": obj.get("method"),
            "user_token": obj.get("user_token"),
            "acting_user_token": obj.get("acting_user_token"),
            "business_token": obj.get("business_token"),
            "amount": obj.get("amount"),
            "memo": obj.get("memo"),
            "tags": obj.get("tags"),
            "original_jit_funding_token": obj.get("original_jit_funding_token"),
            "incremental_authorization_jit_funding_tokens": obj.get("incremental_authorization_jit_funding_tokens"),
            "address_verification": JitAddressVerification.from_dict(obj.get("address_verification")) if obj.get("address_verification") is not None else None,
            "decline_reason": obj.get("decline_reason"),
            "balances": dict(
                (_k, CardholderBalance.from_dict(_v))
                for _k, _v in obj.get("balances").items()
            )
            if obj.get("balances") is not None
            else None
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, Field, StrictStr, confloat, conint, constr, validator

class ChargebackTransitionRequest(BaseModel):
    """
    ChargebackTransitionRequest
    """
    token: Optional[constr(strict=True, max_length=36, min_length=1)] = None
    state: StrictStr = ...
    chargeback_token: constr(strict=True, max_length=36, min_length=1) = ...
    reason: Optional[constr(strict=True, max_length=1024, min_length=1)] = None
    amount: Optional[Union[confloat(ge=0.01, strict=True), conint(ge=1, strict=True)]] = Field(None, description="Representment or prearbitration amount; this is for transitioning to Representment or Prearbitration only")
    regulation_type: Optional[StrictStr] = None
    type: Optional[StrictStr] = None
    __properties = ["token", "state", "chargeback_token", "reason", "amount", "regulation_type", "type"]

    @validator('state')
    def state_validate_enum(cls, v):
        if v not in ('REPRESENTMENT', 'PREARBITRATION', 'PREARB_RESPONDED', 'ARBITRATION', 'CASE_WON', 'CASE_LOST', 'WRITTEN_OFF_ISSUER', 'WRITTEN_OFF_PROGRAM'):
            raise ValueError("must be one of enum values ('REPRESENTMENT', 'PREARBITRATION', 'PREARB_RESPONDED', 'ARBITRATION', 'CASE_WON', 'CASE_LOST', 'WRITTEN_OFF_ISSUER', 'WRITTEN_OFF_PROGRAM')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ChargebackTransitionRequest:
        """Create an instance of ChargebackTransitionRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ChargebackTransitionRequest:
        """Create an instance of ChargebackTransitionRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return ChargebackTransitionRequest.parse_obj(obj)

        _obj = ChargebackTransitionRequest.parse_obj({
            "token": obj.get("token"),
            "state": obj.get("state"),
            "chargeback_token": obj.get("chargeback_token"),
            "reason": obj.get("reason"),
            "amount": obj.get("amount"),
            "regulation_type": obj.get("regulation_type"),
            "type": obj.get("type")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, Field, StrictStr, confloat, conint, constr

class FundingRequestModel(BaseModel):
    """
    FundingRequestModel
    """
    user_token: constr(strict=True, max_length=36, min_length=1) = ...
    order_number: StrictStr = ...
    amount: Union[confloat(ge=0.1, strict=True), conint(ge=1, strict=True)] = ...
    funding_source: Optional[StrictStr] = Field(None, description="Payment card or ACH account number")
    funding_address: Optional[StrictStr] = None
    fundgpadetail: Optional[StrictStr] = None
    order_token: Optional[constr(strict=True, max_length=36, min_length=1)] = None
    currency_code: Optional[StrictStr] = None
    __properties = ["user_token", "order_number", "amount", "funding_source", "funding_address", "fundgpadetail", "order_token", "currency_code"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> FundingRequestModel:
        """Create an instance of FundingRequestModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> FundingRequestModel:
        """Create an instance of FundingRequestModel from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return FundingRequestModel.parse_obj(obj)

        _obj = FundingRequestModel.parse_obj({
            "user_token": obj.get("user_token"),
            "order_number": obj.get("order_number"),
            "amount": obj.get("amount"),
            "funding_source": obj.get("funding_source"),
            "funding_address": obj.get("funding_address"),
            "fundgpadetail": obj.get("fundgpadetail"),
            "order_token": obj.get("order_token"),
            "currency_code": obj.get("currency_code")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictStr, validator

class Transit(BaseModel):
    """
    Transit
    """
    transaction_type: Optional[StrictStr] = None
    transportation_mode: Optional[StrictStr] = None
    __properties = ["transaction_type", "transportation_mode"]

    @validator('transaction_type')
    def transaction_type_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('PRE_FUNDED', 'REAL_TIME_AUTHORIZED', 'POST_AUTHORIZED_AGGREGATED', 'AUTHORIZED_AGGREGATED_SPLIT_CLEARING', 'OTHER', 'DEBIT_RECOVERY'):
            raise ValueError("must be one of enum values ('PRE_FUNDED', 'REAL_TIME_AUTHORIZED', 'POST_AUTHORIZED_AGGREGATED', 'AUTHORIZED_AGGREGATED_SPLIT_CLEARING', 'OTHER', 'DEBIT_RECOVERY')")
        return v

    @validator('transportation_mode')
    def transportation_mode_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('BUS', 'TRAIN', 'WATER_BORNE_VEHICLE', 'TOLL', 'PARKING', 'TAXI', 'PARA_TRANSIT', 'SELF_DRIVE_VEHICLE', 'COACH', 'LOCOMOTIVE', 'POWERED_MOTOR_VEHICLE', 'TRAILER', 'INTER_CITY', 'CABLE_CAR'):
            raise ValueError("must be one of enum values ('BUS', 'TRAIN', 'WATER_BORNE_VEHICLE', 'TOLL', 'PARKING', 'TAXI', 'PARA_TRANSIT', 'SELF_DRIVE_VEHICLE', 'COACH', 'LOCOMOTIVE', 'POWERED_MOTOR_VEHICLE', 'TRAILER', 'INTER_CITY', 'CABLE_CAR')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Transit:
        """Create an instance of Transit from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Transit:
        """Create an instance of Transit from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return Transit.parse_obj(obj)

        _obj = Transit.parse_obj({
            "transaction_type": obj.get("transaction_type"),
            "transportation_mode": obj.get("transportation_mode")
        })
        return _obj

